#
# spec file for package python-django-q
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-q
Version:        1.3.9
Release:        4.1
Summary:        Multiprocessing Distributed Task Queue for Django
License:        MIT
URL:            https://django-q.readthedocs.org
Source:         https://files.pythonhosted.org/packages/source/d/django-q/django-q-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-arrow
Requires:       python-blessed
Requires:       python-django-picklefield
Requires:       python-redis
Suggests:       python-croniter
Suggests:       python-django-q-rollbar >= 0.1
Suggests:       python-django-q-sentry >= 0.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module arrow}
BuildRequires:  %{python_module blessed}
BuildRequires:  %{python_module croniter}
BuildRequires:  %{python_module django-picklefield}
BuildRequires:  %{python_module django-redis}
BuildRequires:  %{python_module hiredis}
BuildRequires:  %{python_module pymongo}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis}
BuildRequires:  dos2unix
# /SECTION
%python_subpackages

%description
This package provides a multiprocessing distributed task queue for Django.

%prep
%autosetup -n django-q-%{version} -p1

# Fix permissions
find -name "*.po" | xargs chmod a-x
chmod a-x README.rst CHANGELOG.md LICENSE

# Fix encoding
dos2unix README.rst

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/django_q/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#%%check
# Tests require a docker container to run

%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE
%{python_sitelib}/django_q
%{python_sitelib}/django_q-%{version}*-info

%changelog
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Aug  5 2022 Andreas Schneider <asn@cryptomilk.org>
- Add missing Requires for python-redis
  * redis is the default broker of dango q clusters, see
    https://django-q.readthedocs.io/en/latest/brokers.html
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Enable multiflavor so that we can pin mailmain to Python 3.9
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.9
  * Sets Autofield
  * Fix RemovedInDjango41Warning
  * Create codeql-analysis.yml
  * Codecov_fixes. Got coverage again
  * Feature/improves multiple databases support
  * Fix for SSL errors in #422
  * Fixes #314 - Convert func to its import path str so that
    resubmitting failed task works
  * Add "qmemory" command
  * Allow tasks to be scheduled on a specific cluster
  * Fixes #225 - Successful tasks grow beyond SAVE_LIMIT
  * Update documentation for new retry time default
  * Fixes deprecated count method
  * Adds long polling support
  * Use 'timezone.localtime()' when calculating the next run time
  * Add a warning for misconfiguration.
  * Add broker name in Schedule and enhanced Queued Tasks list
    display admin
  * Add example of http health check
  * Added german translation
  * Try to get SQS queue before creating it
  * Empty dictionary as configuration value for SQS
  * Model.unicode() has no effect in Python 3.X
  * Fix deprecation warning RemovedInDjango40Warning
  * Fix for #424 TypeError: can't pickle _thread.lock objects
  * [WIP]Change Django documentation links and URLs to a
    supported version (v1.8 -> v2.2)
  * Add attempt_count to limit the number of times a filed task
    will be re-attempted
  * Updates to Django 3.1
  * Resource limits: max rss memory limit for workers
* Tue Jul  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.1
  - Ability to customize schedule creation
  - django-picklefield 3.0.1 has requirement Django>=2.2
  - select_for_update could not be used outside of a transaction
  - Support for Cron expressions
  - Updates packages
  - Adds hint, some linting and a release drafter
  - Use 'force_str' instead of deprecated 'force_text'
  - Add missing migration
* Fri Jun 12 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 1.2.4
  * When sync=True, re-raise exceptions from the worker
  * Fix issue when using USE_TZ=False with MySQL
  * Fix issues when using multiple databases with a database router
  * Expose list of workers and their states via API
  * Add missing migration
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Convert to f-strings #415 (Koed00)
  * Run task at a specific time #407
  * Question about Multiple Clusters #401
  * Ability to use a Redis URI #402
  * Latest versions of Arrow will break django-q #377
  * Timeout override is lost when sent to broker #332
  * "InterfaceError: connection already closed" being raised when a test is run #326
  * scheduler creating duplicate tasks in multiple cluster environment #231
* Mon Jan 13 2020 pgajdos@suse.com
- be able to test also for 15
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Oct  2 2019 pgajdos@suse.com
- initial version 1.0.2, needed by HyperKitty [SLE-7686]
